<?php

declare(strict_types=1);

namespace Dedi\SyliusImportExportPlugin\Controller;

use Dedi\SyliusImportExportPlugin\Processor\ExportProcessorInterface;
use Dedi\SyliusImportExportPlugin\Registry\ExporterRegistry;
use Exception;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

class ExportController extends AbstractController
{
    private readonly ExportProcessorInterface $exportProcessor;

    private readonly ExporterRegistry $exportRegistry;

    public function __construct(ExportProcessorInterface $exportProcessor, ExporterRegistry $exportRegistry)
    {
        $this->exportProcessor = $exportProcessor;
        $this->exportRegistry = $exportRegistry;
    }

    public function __invoke(Request $request): Response
    {
        try {
            $exporter = $this->exportRegistry->get($request->get('identifier'));
        } catch (Exception $e) {
            throw $this->createNotFoundException();
        }

        return $this->exportProcessor->process($exporter);
    }
}
